/*
 Copyright (c) 2008 TrueCrypt Developers Association. All rights reserved.

 Governed by the TrueCrypt License 2.8 the full text of which is contained in
 the file License.txt included in TrueCrypt binary and source code distribution
 packages.
*/

#ifndef TC_HEADER_Boot_BootStrings
#define TC_HEADER_Boot_BootStrings

#define TC_BOOT_STR_ERROR					"Error: "
#define TC_BOOT_STR_NO_BOOT_PARTITION		"No bootable partition found"
#define TC_BOOT_STR_UPGRADE_BIOS			"- Upgrade BIOS\r\n- Use a different motherboard model/brand\r\n"

#endif // TC_HEADER_Boot_BootStrings
